 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998-1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* This is where functions related to the print engine are kept */
/* globals for a particular window */
var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
var { XPCOMUtils } = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");

var printEngineContractID      = "@mozilla.org/messenger/msgPrintEngine;1";
var printEngineWindow;
var printEngine;
var printSettings = null;
var printOpener = null;
var silent = null;
var saveSettings = null;
const kMsgBundle = "chrome://messenger/locale/messenger.properties";

function OnUnloadPrintEngine()
{
	var prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
	if (saveSettings != null)
	{
		prefs.setBoolPref("print.save_print_settings", saveSettings);
	}
	
	if (silent!=null)
    {
         prefs.setBoolPref("print.always_print_silent",silent);
    }

}
/* Functions related to startup */
function OnLoadPrintEngine()
{
  printEngine = Components.classes[printEngineContractID].createInstance();
  printEngine = printEngine.QueryInterface(Components.interfaces.nsIMsgPrintEngine);
  InitPrintEngineWindow();
  printEngine.startPrintOperation(printSettings);
}

function PrintEngineCreateGlobals(pdfName)
{
  /* get the print engine instance */
  var printService = Components.classes["@mozilla.org/gfx/printsettings-service;1"].getService(Components.interfaces.nsIPrintSettingsService);
  printSettings = printService.newPrintSettings;
  printSettings.printSilent=true;
  printSettings.printToFile=true;
  printSettings.toFileName=pdfName;
  printSettings.outputFormat=Components.interfaces.nsIPrintSettings.kOutputFormatPDF;
  printSettings.printBGImages = true;
  printSettings.showPrintProgress = true;
  printSettings.printBGColors = true;
  printSettings.footerStrCenter = "";
  printSettings.footerStrLeft="";
  printSettings.footerStrRight="";
  printSettings.headerStrCenter = "";
  printSettings.headerStrLeft="";
  printSettings.headerStrRight="";
  printSettings.shrinkToFit=true;

  var prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
  if(prefs.getPrefType("print.always_print_silent") && prefs.getBoolPref("print.always_print_silent")!=0 && prefs.getBoolPref("print.always_print_silent"))
          silent=true;
       else
          silent=false;
	  
  if(prefs.getPrefType("print.save_print_settings") && prefs.getBoolPref("print.save_print_settings")!=0 && prefs.getBoolPref("print.save_print_settings"))
        saveSettings=true;
      else
        saveSettings=false;

  prefs.setBoolPref("print.always_print_silent",true);
  prefs.setBoolPref("print.save_print_settings", false);


  if (printSettings) {
    printSettings.isCancelled = false;
  }
}

var PrintPreviewListener = {
  getPrintPreviewBrowser() {
    var browser = document.getElementById("ppBrowser");
    if (!browser) {
      browser = document.createElement("browser");
      browser.setAttribute("id", "ppBrowser");
      browser.setAttribute("flex", "1");
      browser.setAttribute("disablehistory", "true");
      browser.setAttribute("disablesecurity", "true");
      browser.setAttribute("type", "content");
      document.documentElement.appendChild(browser);
    }
    return browser;
  },
  getSourceBrowser() {
    return document.getElementById("content");
  },
  getNavToolbox() {
    return document.getElementById("content");
  },
  onEnter() {
	setPPTitle(document.getElementById("content").contentDocument.title);
    document.getElementById("content").collapsed = true;
    printEngine.showWindow(true);
  },
  onExit() {
    window.close();
  },
};

function getBundle(aURI)
{
  if (!aURI)
    return null;

  var bundle = null;
  try
  {
    var strBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"].
      getService(Components.interfaces.nsIStringBundleService);
    bundle = strBundleService.createBundle(aURI);
  }
  catch (ex)
  {
    bundle = null;
    debug("Exception getting bundle " + aURI + ": " + ex);
  }

  return bundle;
}

function setPPTitle(aTitle)
{
  var title = aTitle;
  try {
  var gBrandBundle = document.getElementById("bundle_brand");
  if (gBrandBundle) {
    var msgBundle = this.getBundle(kMsgBundle);
    if (msgBundle) {
        var brandStr = gBrandBundle.getString("brandShortName")
        var array = [title, brandStr];
        title = msgBundle.formatStringFromName("PreviewTitle", array, array.length);
      }
    }
  } catch (e) {}
  document.title = title;
}

// Pref listener constants
var gStartupPPObserver =
{
  observe(subject, topic, prefName)
  {
    PrintUtils.printPreview(PrintPreviewListener);
  },
};

function ReplaceWithSelection()
{
  var selection = printOpener.content.getSelection();

  if ( selection != "" ) {
    var range = selection.getRangeAt( 0 );
    var contents = range.cloneContents();

    var bodies = window.content.document.getElementsByTagName( "body" );

    /* Replace the content of <body> with the users' selection. */
    if ( bodies.length > 0 ) {
      bodies[0].innerHTML = "";
      bodies[0].appendChild( contents );
    }
  }
}

function InitPrintEngineWindow()
{
  /* Store the current opener for later access in ReplaceWithSelection() */
  printOpener = opener;

  /* Register the event listener to be able to replace the document
   * content with the user selection when loading is finished.
   */
 // document.getElementById("content").addEventListener("load", ReplaceWithSelection, true);

  /* Tell the nsIPrintEngine object what window is rendering the email */
  printEngine.setWindow(window);

  /* hide the printEngine window.  see bug #73995 */

  /* See if we got arguments.
   * Window was opened via window.openDialog.  Copy argument
   * and perform compose initialization
   */
  if ( window.arguments && window.arguments[0] != null )
  {
    var numSelected = window.arguments[0];
    var uriArray = window.arguments[1];
    var statusFeedback = null;

    printEngine.doPrintPreview = false;
    printEngine.showWindow(false);
    printEngine.setMsgType(Components.interfaces.nsIMsgPrintEngine.MNAB_START);
    printEngine.setParentWindow(null);

    printEngine.setStatusFeedback(statusFeedback);
    printEngine.setStartupPPObserver(gStartupPPObserver);

    if (numSelected > 0) {
      printEngine.setPrintURICount(numSelected);
      for (var i = 0; i < numSelected; i++) {
        printEngine.addPrintURI(uriArray[i]);
        //dump(uriArray[i] + "\n");
      }
    }

    PrintEngineCreateGlobals(window.arguments[2]);
	
	window.addEventListener("DOMWindowClose",OnUnloadPrintEngine,false);

  }
}

function ClearPrintEnginePane()
{
  if (window.frames["content"].location.href != "about:blank")
      window.frames["content"].location.href = "about:blank";
}

function StopUrls()
{
  printEngine.stopUrls();
}

function PrintEnginePrint()
{
  printEngineWindow = window.openDialog("chrome://messenger/content/msgPrintEngine.xhtml", "", "chrome,dialog=no,all,centerscreen", false);
}

function PrintEnginePrintPreview()
{
  printEngineWindow = window.openDialog("chrome://messenger/content/msgPrintEngine.xhtml", "", "chrome,dialog=no,all,centerscreen", true);
}
